@@ -1,7 +1,5 @@
 package Mason::Component;
-BEGIN {
-  $Mason::Component::VERSION = '2.20';
-}
+$Mason::Component::VERSION = '2.22';
 use Moose;    # no Mason::Moose - don't want StrictConstructor
 use MooseX::HasDefaults::RO;
 use Method::Signatures::Simple;
@@ -69,7 +67,7 @@ method no_wrap ($class:) {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -194,10 +192,10 @@ parent.
 
 This method is called when the request path has a path_info portion, to
 determine whether the path_info is allowed. Default is false. See
-L<Mason::Manual::RequestDispatch/Partial Paths|Mason::Manual::RequestDispatch>.
+L<Mason::Manual::RequestDispatch|Mason::Manual::RequestDispatch/Partial Paths>.
 
     <%class>
-    CLASS->allow_path_info(1);
+    method allow_path_info { 1 }
     </%class>
 
 =back
@@ -242,7 +240,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
